document.addEventListener('DOMContentLoaded', () => {
    const encodeProgress = document.getElementById('encodeProgress');
    const saveButton = document.getElementById('saveCapture');
    const closeButton = document.getElementById('close');
    const review = document.getElementById('review');
    const status = document.getElementById('status');
    const spinner = document.querySelector('.spinner'); // Select the spinner element
    let format;
    let audioURL;
    let encoding = false;
    //get userid
    let userId; // Declare a global variable
    chrome.storage.sync.get(['userid'], function(result) {
        console.log('user ID:', result.userid);
        userId = result.userid; // Assign the value to the global variable
      });
    chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
        if (request.type === "createTab") {
            format = request.format;
            let startID = request.startID;
            status.innerHTML = "Please wait...";
            closeButton.onclick = () => {
                chrome.runtime.sendMessage({cancelEncodeID: startID});
                chrome.tabs.getCurrent((tab) => {
                    chrome.tabs.remove(tab.id);
                });
            }

            //if the encoding completed before the page has loaded
            if (request.audioURL) {
                encodeProgress.style.width = '100%';
                status.innerHTML = "File is ready to be scanned!";
                generateSave(request.audioURL);
            } else {
                encoding = true;
            }
        }

        //when encoding completes
        if (request.type === "encodingComplete" && encoding) {
            encoding = false;
            status.innerHTML = "File is ready to be scanned!";
            encodeProgress.style.width = '100%';
            generateSave(request.audioURL);
        }
        //updates encoding process bar upon messages
        if (request.type === "encodingProgress" && encoding) {
            encodeProgress.style.width = `${request.progress * 100}%`;
        }

        function generateSave(url) {
            // Show the loading spinner
            spinner.style.display = 'block';

            // Create a new FormData object
            const formData = new FormData();

            // Append the audio file to the FormData object
            fetch(url)
                .then(response => response.blob())
                .then(blob => {
                    formData.append('audio', blob, 'recorded_audio.wav');
                    // Create a new URL object from the Blob
                    const audioBlobUrl = URL.createObjectURL(blob);

                    // Set the audio source to the URL
                    const recordedAudio = document.getElementById('recordedAudio');
                    recordedAudio.src = audioBlobUrl;
                    recordedAudio.controls = true; // Show controls for the audio element
                    formData.append("id", userId);
                    // Make a fetch request to the endpoint
                    fetch('https://voicy00.pythonanywhere.com/predict', {
    method: 'POST',
    body: formData
})
.then(response => response.json())
.then(data => {
    // For non-subscribers message
    var message = data.message;
    console.log(message);
    if (typeof message != "undefined") {
        document.getElementById("message").innerHTML = message + "<span style='color:purple'> <br>Cancel Anytime for Free <br> 100% Secure Payment With Paypal or Credit Card</span> <br>";
        var paymentButton = document.createElement("button");
        paymentButton.innerHTML = "Get Access Now for $24.99/month";
        paymentButton.onclick = function() {
            location.href = "https://aivoicedetector.com/pricing";
        }
        paymentButton.style.backgroundColor = "purple";
        paymentButton.style.border = "none";
        paymentButton.style.color = "white";
        paymentButton.style.padding = "12px 24px";
        paymentButton.style.textAlign = "center";
        paymentButton.style.textDecoration = "none";
        paymentButton.style.display = "inline-block";
        paymentButton.style.fontSize = "16px";
        document.getElementById("message").appendChild(paymentButton);
    }
    // Hide the loading spinner
    spinner.style.display = 'none';

    // Display the result in the HTML page
    const resultLabel = document.getElementById('resultLabel');
    const probabilities = document.getElementById('probabilities');
    probabilities.innerHTML = '';

    // Calculate the sum of all probabilities
    let sum = data.class_probabilities.reduce((acc, prob) => acc + prob[1], 0);
    let maxProbability = 0;
    let classLabel = '';

    // Normalize probabilities and display them as percentages
    data.class_probabilities.forEach(probability => {
        const listItem = document.createElement('li');
        const normalizedProbability = ((probability[1] / sum) * 100).toFixed(2);
        listItem.textContent = `${probability[0]}: ${normalizedProbability}%`;
        probabilities.appendChild(listItem);

        // Determine if this is the max probability and store it
        if (normalizedProbability > maxProbability) {
            maxProbability = normalizedProbability;
            classLabel = probability[0];
            sendResultsToPopup(maxProbability, classLabel);
        }
    });

    // Display a message based on the highest probability
    if (maxProbability >= 80) {
        resultLabel.innerHTML = `Based on our model, the audio is <span style="color: purple; font-weight: bold;">highly likely to be ${classLabel}</span>. If you have doubts about the audio, take precautions.
        `;
    } else {
        resultLabel.innerHTML = `The results are <span style="color: purple; font-weight: bold;">inconclusive</span>. Please record a higher-quality audio. Make sure the person in the audio speaks more words, and there's less background music.`;
    }    
})
.catch(error => {
    console.error('Error:', error);
});

                });
        }
    });
  
});

const sendResultsToPopup = (maxProbability, classLabel) => {
    // Send message to popup.js with results
    chrome.runtime.sendMessage({
        type: "displayResults",
        maxProbability,
        classLabel
    });
};
