let interval;
let timeLeft;
let startTime;

const displayStatus = function() {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        const status = document.getElementById("status");
        const timeRem = document.getElementById("timeRem");
        const startButton = document.getElementById('start');
        const finishButton = document.getElementById('finish');
        const cancelButton = document.getElementById('cancel');

        chrome.runtime.sendMessage({ currentTab: tabs[0].id }, (response) => {
            if (response) {
                chrome.storage.sync.get({
                    maxTime: 7000, // Default value set to 7 seconds
                    limitRemoved: false
                }, (options) => {
                    startTime = response.startTime; // Store the start time of recording
                    timeLeft = options.maxTime - (Date.now() - startTime);

                    status.innerHTML = "Tab is currently being captured";

                    if (options.limitRemoved) {
                        timeRem.innerHTML = `${parseTime(Date.now() - startTime)}`;
                        interval = setInterval(() => {
                            timeRem.innerHTML = `${parseTime(Date.now() - startTime)}`;
                        }, 1000);
                    } else {
                        timeRem.innerHTML = `${parseTime(timeLeft)} remaining`;
                        interval = setInterval(() => {
                            timeLeft = options.maxTime - (Date.now() - startTime);
                            if (timeLeft <= 0) {
                                stopRecording();
                                return;
                            }
                            timeRem.innerHTML = `${parseTime(timeLeft)} remaining`;
                        }, 1000);
                    }
                });

                finishButton.style.display = "block";
                cancelButton.style.display = "block";
            } else {
                startButton.style.display = "block";
            }
        });
    });
}

const stopRecording = function() {
    clearInterval(interval);
    chrome.runtime.sendMessage("stopCapture");
}

const parseTime = function(time) { 
    let minutes = Math.floor((time / 1000) / 60);
    let seconds = Math.floor((time / 1000) % 60);
    if (minutes < 10 && minutes >= 0) {
        minutes = '0' + minutes;
    } else if (minutes < 0) {
        minutes = '00';
    }
    if (seconds < 10 && seconds >= 0) {
        seconds = '0' + seconds;
    } else if (seconds < 0) {
        seconds = '00';
    }
    return `${minutes}:${seconds}`
}

//manipulation of the displayed buttons upon message from background
chrome.runtime.onMessage.addListener((request, sender) => {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        const status = document.getElementById("status");
        const timeRem = document.getElementById("timeRem");
        const startButton = document.getElementById('start');
        const finishButton = document.getElementById('finish');
        const cancelButton = document.getElementById('cancel');
        if (request.captureStarted && request.captureStarted === tabs[0].id) {
            chrome.storage.sync.get({
                maxTime: 7000,
                limitRemoved: false
            }, (options) => {
                startTime = request.startTime; // Store the start time of recording
                timeLeft = options.maxTime - (Date.now() - startTime);
                status.innerHTML = "Tab is currently being captured";
                if (options.limitRemoved) {
                    timeRem.innerHTML = `${parseTime(Date.now() - request.startTime)}`;
                    interval = setInterval(() => {
                        timeRem.innerHTML = `${parseTime(Date.now() - request.startTime)}`
                    }, 1000);
                } else {
                    timeRem.innerHTML = `${parseTime(timeLeft)} remaining`;
                    interval = setInterval(() => {
                        timeLeft = options.maxTime - (Date.now() - startTime);
                        if (timeLeft <= 0) {
                            stopRecording();
                            return;
                        }
                        timeRem.innerHTML = `${parseTime(timeLeft)} remaining`;
                    }, 1000);
                }
            });
            finishButton.style.display = "block";
            cancelButton.style.display = "block";
            startButton.style.display = "none";
        } else if (request.captureStopped && request.captureStopped === tabs[0].id) {
            status.innerHTML = "";
            finishButton.style.display = "none";
            cancelButton.style.display = "none";
            startButton.style.display = "block";
            timeRem.innerHTML = "";
            clearInterval(interval);
        }
    });
});

document.addEventListener('DOMContentLoaded', function() {
    const loginForm = document.getElementById('login');
    const loginheader = document.getElementById('loginheader');
    const recordingButton = document.getElementById('start');
    const otherButtonsContainer = document.getElementById('otherButtons');
    const logoutButton = document.getElementById('logout');

    // Hide Start Recording and other buttons initially
    recordingButton.style.display = 'none';
    otherButtonsContainer.style.display = 'none';

    // Check if user is already logged in
    chrome.storage.sync.get(['isLoggedIn'], function(data) {
        if (data.isLoggedIn) {
            // User is already logged in, show recording button and other buttons
            loginForm.style.display = 'none';
            loginheader.style.display = 'none';
            recordingButton.style.display = 'block';
            otherButtonsContainer.style.display = 'block';
            logoutButton.style.display = 'block';
            displayStatus();
        } else {
            // User is not logged in, show login form
            loginForm.style.display = 'block';
            loginheader.style.display = 'block';
        }
    });

    // Event listener for login form submission
    loginForm.addEventListener('submit', async function(event) {
        event.preventDefault();
        const email = document.getElementById('email').value;
        const password = document.getElementById('password').value;

        // Perform login verification
        try {
            const response = await fetch('https://zoow.pythonanywhere.com/login', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ email, password }),
            });
            if (response.ok) {
                // Hide login form and show other buttons including Start Recording
                loginForm.style.display = 'none';
                loginheader.style.display = 'none';
                recordingButton.style.display = 'block';
                otherButtonsContainer.style.display = 'block';
                logoutButton.style.display = 'block';
                const data = await response.json();
                console.log("hello", data.user_id);
                chrome.storage.sync.set({ isLoggedIn: true, userid: data.user_id });
                displayStatus();


                
            } else {
                alert('Invalid email or password. Please try again.');
            }
        } catch (error) {
            console.error('Error:', error);
            alert('An error occurred. Please try again later.');
        }
    });

    // Logout functionality
    logoutButton.addEventListener('click', function() {
        chrome.storage.sync.remove('isLoggedIn');
        loginForm.style.display = 'block';
        loginheader.style.display = 'block';
        recordingButton.style.display = 'none';
        otherButtonsContainer.style.display = 'none';
        logoutButton.style.display = 'none';
    });
    const startKey = document.getElementById("startKey");
    const endKey = document.getElementById("endKey");
    const startButton = document.getElementById('start');
    const finishButton = document.getElementById('finish');
    const cancelButton = document.getElementById('cancel');
    startButton.onclick = () => { chrome.runtime.sendMessage("startCapture") };
    finishButton.onclick = () => { chrome.runtime.sendMessage("stopCapture") };
    cancelButton.onclick = () => { chrome.runtime.sendMessage("cancelCapture") };
    chrome.runtime.getPlatformInfo((info) => {
        if (info.os === "mac") {
            startKey.innerHTML = "Command + Shift + U to start capture on current tab";
            endKey.innerHTML = "Command + Shift + X to stop capture on current tab";
        } else {
            startKey.innerHTML = "Ctrl + Shift + S to start capture on current tab";
            endKey.innerHTML = "Ctrl + Shift + X to stop capture on current tab";
        }
    })

    chrome.runtime.sendMessage({query: "isAudioPlaying"}, function(response) {
        const statusElement = document.getElementById('status');
        chrome.storage.sync.get(['isLoggedIn'], function(data) {
            if (data.isLoggedIn) {
                if (response.isAudioPlaying) {
                    statusElement.textContent = "Audio is playing";
                    loadingIndicator.style.display = 'block';
                    chrome.runtime.sendMessage("startCapture");
                } else {
                    statusElement.textContent = "No audio playing";
                }
            } else {
                statusElement.textContent = "Please login"; // Or any appropriate message
            }
        });
    });
    
});

// Add listener to receive results from complete.js
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.type === "displayResults") {
        // Hide the loading indicator
        const loadingIndicator = document.getElementById('loadingIndicator');
        loadingIndicator.style.display = 'none';

        // Display results in the popup HTML
        const resultLabel = document.getElementById('resultLabel');
        resultLabel.innerHTML = `Based on our model, the audio is <span style="color: purple; font-weight: bold;">highly likely to be ${request.classLabel}</span>. If you have doubts about the audio, take precautions.`;
    }
});

